==> mobGameSDK-5.3.2-sources.jar: com/game/sdk/comon/constants/ConstantApi.java <==
package com.game.sdk.comon.constants;

/**
 * Created by dungnv
 */

public interface ConstantApi {


    //    String BASE_URL = "https://id.funtap.vn/ApiIdV5/";
    String APP_UR = "APP_UR";
    //    String BASE_URL = "https://stg-core.sdkmain.com/";
    String BASE_URL = "https://core.sdkmain.com/";
    String URL_LOGIN_PLAYNOW = "api/v1/apps/{app_key}/{app_version}/auth/playNow";
    String URL_LOGIN_EMAIL = "api/v1/apps/{app_key}/{app_version}/auth/login";
    String URL_LOGIN_GOOGLE = "/api/v1/apps/{app_key}/{app_version}/auth/google";
    String URL_LOGIN_FACEBOOK = "api/v1/apps/{app_key}/{app_version}/auth/facebook";

    String URL_GET_AUTH_CONFIG = "api/v1/apps/{app_key}/{app_version}/configs/auth";
    String URL_GET_SDK_CONFIG = "api/v1/apps/{app_key}/{app_version}/configs/important";
    String URL_GET_USER = "api/v1/apps/{app_key}/{app_version}/users/basicInfo";
    String URL_GET_MESS_IN_GAME = "api/v1/apps/{app_key}/{app_version}/inMessages";
    String URL_CONNECT_FACEBOOK = "api/v1/apps/{app_key}/{app_version}/users/connectFacebook";
    String URL_SAVE_CHARACTOR = "api/v1/apps/{app_key}/{app_version}/users/character/save";


    /**
     * INTERACT
     */
    String URL_BASE_INTERACT = "https://interact.sdkmain.com/"; // product
    //    String URL_BASE_INTERACT = "https://stg-interact.sdkmain.com/ ";//Staging
    String URL_SAVE_FCM = "sdk/device-tokens/fcm";

    /**
     * PAYTECH
     */
    String URL_BASE_PAYTECH = "https://pay.sdkmain.com/";
    //     String URL_BASE_PAYTECH = "https://stg-api.platformjk.com/";//Staging
    String URL_VERIFY_PURCHASE = "payments/sdk/excute/{order_no}";
    String URL_PURCHASE_PRODUCTS = "wv/sdk/items";
    String URL_RETRY_PURCHASE = "payments/sdk/retry";

    String ISSUE_URL = "https://issue.sdkmain.com/";

    /**
     * ---------------------------------------------------------------------------------------------
     */
    String URL_BASE_ADS = "https://track.sdkmain.com/";
    String URL_SAVE_AII = "api/data_rel/sdk_fb";


    /**
     * ---------------------------------------------------------------------------------------------
     */

    String URL_WEBVIEW_REGISTER = "v1/apps/{app_key}/{app_version}/register/email";
    String URL_WEBVIEW_DASHBOARD_NEWS = "v1/apps/{app_key}/{app_version}/dashboard/news";
    String URL_WEBVIEW_DASHBOARD_EVENTS = "v1/apps/{app_key}/{app_version}/dashboard/events";
    String URL_WEBVIEW_DASHBOARD_REPORTS = "api/v1/apps/{app_key}/{app_version}/ticket_db/listreport2";
    String URL_WEBVIEW_DASHBOARD_MENU = "v1/apps/{app_key}/{app_version}/dashboard/menu";
    String URL_WEBVIEW_TERM = "v1/apps/{app_key}/{app_version}/policy";
    String HEADER_X_AUTHIRIZATION = "X-Authorization";
    String HEADER_ATHORIZATION = "Authorization";
    String HEADER_APP_KEY = "X-Request";
    String HEADER_APP_VERSION = "app-Version";
    String HEADER_SDK_VERSION = "sdk-Version";
    String HEADER_SDK_LOCATLE = "sdk-locale";
    String HEADER_ACCESS_TOKEN = "access_token";
    String HEADER_DEVICE_OS = "device-Os";
    String HEADER_DEVICE_NAME = "device-Name";
    String HEADER_ADVERTISING_ID = "advertising-id";
    String HEADER_TOKEN = "token";

}

==> mobGameSDK-5.3.3-sources.jar: com/game/sdk/comon/constants/ConstantApi.java <==
package com.game.sdk.comon.constants;

/**
 * Created by dungnv
 */

public interface ConstantApi {


    //    String BASE_URL = "https://id.funtap.vn/ApiIdV5/";
    String APP_UR = "APP_UR";
    //    String BASE_URL = "https://stg-core.sdkmain.com/";
    String BASE_URL = "https://core.sdkmain.com/";
    String URL_LOGIN_PLAYNOW = "api/v1/apps/{app_key}/{app_version}/auth/playNow";
    String URL_LOGIN_EMAIL = "api/v1/apps/{app_key}/{app_version}/auth/login";
    String URL_LOGIN_GOOGLE = "/api/v1/apps/{app_key}/{app_version}/auth/google";
    String URL_LOGIN_FACEBOOK = "api/v1/apps/{app_key}/{app_version}/auth/facebook";

    String URL_GET_AUTH_CONFIG = "api/v1/apps/{app_key}/{app_version}/configs/auth";
    String URL_GET_SDK_CONFIG = "api/v1/apps/{app_key}/{app_version}/configs/important";
    String URL_GET_USER = "api/v1/apps/{app_key}/{app_version}/users/basicInfo";
    String URL_GET_MESS_IN_GAME = "api/v1/apps/{app_key}/{app_version}/inMessages";
    String URL_CONNECT_FACEBOOK = "api/v1/apps/{app_key}/{app_version}/users/connectFacebook";
    String URL_SAVE_CHARACTOR = "api/v1/apps/{app_key}/{app_version}/users/character/save";


    /**
     * INTERACT
     */
    String URL_BASE_INTERACT = "https://interact.sdkmain.com/"; // product
    //    String URL_BASE_INTERACT = "https://stg-interact.sdkmain.com/ ";//Staging
    String URL_SAVE_FCM = "sdk/device-tokens/fcm";

    /**
     * PAYTECH
     */
    String URL_BASE_PAYTECH = "https://pay.sdkmain.com/";
    //         String URL_BASE_PAYTECH = "https://stg-pay.sdkmain.com/";//Staging
    String URL_VERIFY_PURCHASE = "payments/sdk/excute/{order_no}";
    String URL_PURCHASE_PRODUCTS = "wv/sdk/items";
    String URL_RETRY_PURCHASE = "payments/sdk/retry";
    String URL_GET_LIST_ITEM = "products/items/sdk";
    String URL_INITIAL_PURCHASE = "payments/sdk";

    String ISSUE_URL = "https://issue.sdkmain.com/";

    /**
     * ---------------------------------------------------------------------------------------------
     */
    String URL_BASE_ADS = "https://track.sdkmain.com/";
    String URL_SAVE_AII = "api/data_rel/sdk_fb";


    /**
     * ---------------------------------------------------------------------------------------------
     */

    String URL_WEBVIEW_REGISTER = "v1/apps/{app_key}/{app_version}/register/email";
    String URL_WEBVIEW_DASHBOARD_NEWS = "v1/apps/{app_key}/{app_version}/dashboard/news";
    String URL_WEBVIEW_DASHBOARD_EVENTS = "v1/apps/{app_key}/{app_version}/dashboard/events";
    String URL_WEBVIEW_DASHBOARD_REPORTS = "api/v1/apps/{app_key}/{app_version}/ticket_db/listreport2";
    String URL_WEBVIEW_DASHBOARD_MENU = "v1/apps/{app_key}/{app_version}/dashboard/menu";
    String URL_WEBVIEW_TERM = "v1/apps/{app_key}/{app_version}/policy";
    String HEADER_X_AUTHIRIZATION = "X-Authorization";
    String HEADER_ATHORIZATION = "Authorization";
    String HEADER_APP_KEY = "X-Request";
    String HEADER_APP_VERSION = "app-Version";
    String HEADER_SDK_VERSION = "sdk-Version";
    String HEADER_SDK_LOCATLE = "sdk-locale";
    String HEADER_ACCESS_TOKEN = "access_token";
    String HEADER_DEVICE_OS = "device-Os";
    String HEADER_DEVICE_NAME = "device-Name";
    String HEADER_ADVERTISING_ID = "advertising-id";
    String HEADER_TOKEN = "token";

}
